==> haskell-base-compat-0.9.0-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-base-compat/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-compat
version: 0.9.0
id: base-compat-0.9.0-fa16321d7131a0167d57b06b47b516c7
key: basec_3G7TOYmSpaF0smBtbGU3h4
license: MIT
copyright: (c) 2012-2015 Simon Hengel,
           (c) 2014 João Cristóvão,
           (c) 2015 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
synopsis: A compatibility layer for base
description:
    Provides functions available in later versions of @base@ to
    a wider range of compilers, without requiring you to use CPP
    pragmas in your code.  See the
    <https://github.com/haskell-compat/base-compat#readme README>
    for what is covered. Also see the
    <https://github.com/haskell-compat/base-compat/blob/master/CHANGES.markdown changelog>
    for recent changes.
    .
    Note that @base-compat@ does not add any orphan instances.
    There is a separate package,
    @<http://hackage.haskell.org/package/base-orphans base-orphans>@,
    for that.
    .
    In addition, `base-compat` does not backport any data types
    or type classes. See
    @<https://github.com/haskell-compat/base-compat#data-types-and-type-classes this section of the README>@
    for more info.
category: Compatibility
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
exposed: True
exposed-modules:
    Control.Concurrent.Compat Control.Concurrent.MVar.Compat
    Control.Monad.Compat Control.Monad.ST.Lazy.Unsafe.Compat
    Control.Monad.ST.Unsafe.Compat Data.Bits.Compat Data.Bool.Compat
    Data.Complex.Compat Data.Either.Compat Data.Foldable.Compat
    Data.Function.Compat Data.Functor.Compat Data.Functor.Const.Compat
    Data.IORef.Compat Data.List.Compat Data.Monoid.Compat
    Data.Ratio.Compat Data.STRef.Compat Data.String.Compat
    Data.Version.Compat Data.Word.Compat Debug.Trace.Compat
    Foreign.Compat Foreign.ForeignPtr.Safe.Compat
    Foreign.ForeignPtr.Unsafe.Compat Foreign.Marshal.Alloc.Compat
    Foreign.Marshal.Array.Compat Foreign.Marshal.Compat
    Foreign.Marshal.Safe.Compat Foreign.Marshal.Unsafe.Compat
    Foreign.Marshal.Utils.Compat Numeric.Compat Prelude.Compat
    System.Environment.Compat System.Exit.Compat
    System.IO.Unsafe.Compat Text.Read.Compat
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/base-compat-0.9.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/base-compat-0.9.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/base-compat-0.9.0
hs-libraries: HSbase-compat-0.9.0-3G7TOYmSpaF0smBtbGU3h4
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
haddock-interfaces: /usr/share/doc/haskell-base-compat/html/base-compat.haddock
haddock-html: /usr/share/doc/haskell-base-compat/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-compat-0.9.1-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-base-compat/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-compat
version: 0.9.1
id: base-compat-0.9.1-b27a2a11ed624cad5ac469eab39183ee
key: basec_3Zy8UsyHmBEEwbReR8x1KT
license: MIT
copyright: (c) 2012-2016 Simon Hengel,
           (c) 2014-2016 João Cristóvão,
           (c) 2015-2016 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
synopsis: A compatibility layer for base
description:
    Provides functions available in later versions of @base@ to
    a wider range of compilers, without requiring you to use CPP
    pragmas in your code.  See the
    <https://github.com/haskell-compat/base-compat#readme README>
    for what is covered. Also see the
    <https://github.com/haskell-compat/base-compat/blob/master/CHANGES.markdown changelog>
    for recent changes.
    .
    Note that @base-compat@ does not add any orphan instances.
    There is a separate package,
    @<http://hackage.haskell.org/package/base-orphans base-orphans>@,
    for that.
    .
    In addition, `base-compat` does not backport any data types
    or type classes. See
    @<https://github.com/haskell-compat/base-compat#data-types-and-type-classes this section of the README>@
    for more info.
category: Compatibility
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
exposed: True
exposed-modules:
    Control.Concurrent.Compat Control.Concurrent.MVar.Compat
    Control.Monad.Compat Control.Monad.ST.Lazy.Unsafe.Compat
    Control.Monad.ST.Unsafe.Compat Data.Bits.Compat Data.Bool.Compat
    Data.Complex.Compat Data.Either.Compat Data.Foldable.Compat
    Data.Function.Compat Data.Functor.Compat Data.Functor.Const.Compat
    Data.IORef.Compat Data.List.Compat Data.Monoid.Compat
    Data.Ratio.Compat Data.STRef.Compat Data.String.Compat
    Data.Version.Compat Data.Word.Compat Debug.Trace.Compat
    Foreign.Compat Foreign.ForeignPtr.Safe.Compat
    Foreign.ForeignPtr.Unsafe.Compat Foreign.Marshal.Alloc.Compat
    Foreign.Marshal.Array.Compat Foreign.Marshal.Compat
    Foreign.Marshal.Safe.Compat Foreign.Marshal.Unsafe.Compat
    Foreign.Marshal.Utils.Compat Numeric.Compat Prelude.Compat
    System.Environment.Compat System.Exit.Compat
    System.IO.Unsafe.Compat Text.Read.Compat
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/base-compat-0.9.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/base-compat-0.9.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/base-compat-0.9.1
hs-libraries: HSbase-compat-0.9.1-3Zy8UsyHmBEEwbReR8x1KT
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
haddock-interfaces: /usr/share/doc/haskell-base-compat/html/base-compat.haddock
haddock-html: /usr/share/doc/haskell-base-compat/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
